@@ -8,6 +8,7 @@ from matplotlib.ticker import FuncFormatter
 import pandas as pd
 import matplotlib.lines as lines
 import plotly.graph_objects as go
+from plotly.graph_objs import Layout
 from IPython.display import Image
 
 def pareto_graph(variable, salida='tabla'):
@@ -430,5 +431,57 @@ def fis_bs_sankey(source, target, value,labels_sr,labels_tr,label_show=False, op
           value = value,
           color = color_link
       ))])
+    img_bytes = fig.to_image(format="png",height=600,width=800)
+    return Image(img_bytes)
+    
+def fis_tools_date_elements(df):
+    month = df.index.month
+    year = df.index.year
+    day = df.index.day
+    minute = df.index.minute
+    hour = df.index.hour
+    
+    return(pd.DataFrame({'month':month,'year':year,'day':day,'minute':minute,'hour':hour}))
+    
+def fis_bs_funnel(labels, values, opacity_ins=0.5):
+    opacity = str(opacity_ins)
+    color_rgb = []
+    color_rgb.append('rgba(151, 172, 207, %s)'%(opacity))
+    color_rgb.append('rgba(110, 127, 128, %s)'%(opacity))
+    color_rgb.append('rgba(0, 105, 148, %s)'%(opacity))
+    color_rgb.append('rgba(83, 104, 114, %s)'%(opacity))
+    color_rgb.append('rgba(201, 239, 254, %s)'%(opacity))
+    color_rgb.append('rgba(54, 69, 79, %s)'%(opacity))
+    color_rgb.append('rgba(178, 203, 245, %s)'%(opacity))
+    color_rgb.append('rgba(42, 192, 251, %s)'%(opacity))
+    color_rgb.append('rgba(137, 207, 240, %s)'%(opacity))
+    color_rgb.append('rgba(95, 108, 130, %s)'%(opacity))
+
+    config = {
+      'displayModeBar': False,
+    }
+    
+    color_node = []
+    
+    for i in range(0,len(labels)):
+        color_node.append(color_rgb[i])
+        
+    layout = Layout(
+    paper_bgcolor='rgba(0,0,0,0)',
+    plot_bgcolor='rgba(0,0,0,0)'
+    )
+
+    fig = go.Figure(go.Funnel(
+                    y = labels,
+                    x = values,
+                    textposition = "inside",
+                    textinfo = "value+percent initial",
+                    opacity=opacity_ins,
+                    marker = {"color": color_rgb,}
+                            ),
+    layout=layout)
+    
+
+    
     img_bytes = fig.to_image(format="png",height=600,width=800)
     return Image(img_bytes)
\ No newline at end of file
